<?php

  //--------------------------------------------------------------------------
  // PHPcoord
  // text.php
  //
  // (c) 2005 Jonathan Stott
  //
  // Created on 11-Aug-2005
  //
  // 1.1 - 11 Sep 2005
  //  - Added OSGB36/WGS84 data conversions
  // 1.0 - 11 Aug 2005
  //  - Initial version
  //--------------------------------------------------------------------------


  require_once("phpcoord.php");
?>

<html>

  <head>
    <title>phpcoord Test Script</title>
  </head>

  <body>

    <h1>phpcoord Test Script</h1>

    <h2>Calculate Surface Distance between two Latitudes/Longitudes</h2>

    <p>
      The LatLngDistance function takes two latitudes/longitudes and calculates
      the surface distance between the two in kilometres:
    </p>

    <p>
      <pre>
        $lld1 = new LatLng(40.718119, -73.995667); // New York
        $lld2 = new LatLng(51.499981, -0.125313);  // London
        $d = LatLngDistance($lld1, $lld2);
      </pre>

      <?php
        $lld1 = new LatLng(40.718119, -73.995667); // New York
        echo "New York Lat/Long: " . $lld1->toString() . "<br />";
        $lld2 = new LatLng(51.499981, -0.125313);  // London
        echo "London Lat/Long: " . $lld2->toString() . "<br />";
        $d = LatLngDistance($lld1, $lld2);
        echo "Surface Distance between New York and London: " . $d . "km";
      ?>
    </p>

    <h2>Convert OS Grid Reference to Latitude/Longitude</h2>

    <p>
      Note that the OSGB-Latitude/Longitude conversions use the OSGB36 datum by default. The
      majority of applications use the WGS84 datum, for which the appropriate conversions
      need to be added. See the examples below to see the difference between the two data.
    </p>

    <p>
      Using OSGB36 (convert an OSGB grid reference to a latitude and longitude using the OSGB36 datum):

      <pre>
        $os1 = new OSRef(651409.903, 313177.270);
        $ll1 = OSRefToLatLng($os1);
      </pre>

      <?php
        $os1 = new OSRef(651409.903, 313177.270);
        echo "OS Grid Reference: " . $os1->toString() . " - " . $os1->toSixFigureString() . "<br />";
        $ll1 = OSRefToLatLng($os1);
        echo "Converted to Lat/Long: " . $ll1->toString();
      ?>
    </p>

    <p>
      Using WGS84 (convert an OSGB grid reference to a latitude and longitude using the WGS84 datum):

      <pre>
        $os1w = new OSRef(651409.903, 313177.270);
        $ll1w = OSGB36ToWGS84(OSRefToLatLng($os1w));
      </pre>

      <?php
        $os1w = new OSRef(651409.903, 313177.270);
        echo "OS Grid Reference: " . $os1w->toString() . " - " . $os1w->toSixFigureString() . "<br />";
        $ll1w = OSGB36ToWGS84(OSRefToLatLng($os1w));
        echo "Converted to Lat/Long: " . $ll1w->toString();
      ?>
    </p>

    <h2>Convert Latitude/Longitude to OS Grid Reference</h2>

    <p>
      Note that the OSGB-Latitude/Longitude conversions use the OSGB36 datum by default. The
      majority of applications use the WGS84 datum, for which the appropriate conversions
      need to be added. See the examples below to see the difference between the two data.
    </p>

    <p>
      Using OSGB36 (convert a latitude and longitude using the OSGB36 datum to an OSGB grid reference):

      <pre>
        $ll2 = new LatLng(52.657570301933, 1.7179215806451);
        $os2 = LatLngToOSRef($ll2);
      </pre>

      <?php
        $ll2 = new LatLng(52.657570301933, 1.7179215806451);
        echo "Latitude/Longitude: " . $ll2->toString() . "<br />";
        $os2 = LatLngToOSRef($ll2);
        echo "Converted to OS Grid Ref: " . $os2->toString() . " - " . $os2->toSixFigureString();
      ?>
    </p>

    <p>
      Using WGS84 (convert a latitude and longitude using the WGS84 datum to an OSGB grid reference):

      <pre>
        $ll2w = new LatLng(52.657570301933, 1.7179215806451);
        $os2w = LatLngToOSRef(WGS84ToOSGB36($ll2w));
      </pre>

      <?php
        $ll2w = new LatLng(52.657570301933, 1.7179215806451);
        echo "Latitude/Longitude: " . $ll2->toString() . "<br />";
        $os2w = LatLngToOSRef(WGS84ToOSGB36($ll2w));
        echo "Converted to OS Grid Ref: " . $os2w->toString() . " - " . $os2w->toSixFigureString();
      ?>
    </p>

    <h2>Convert UTM Reference to Latitude/Longitude</h2>

    <p>
      <pre>
        $utm1 = new UTMRef(456463.99, 3335334.05, "E", 12);
        $ll3 = UTMRefToLatLng($utm1);
      </pre>

      <?php
        $utm1 = new UTMRef(456463.99, 3335334.05, "E", 12);
        echo "UTM Reference: " . $utm1->toString() . "<br />";
        $ll3 = UTMRefToLatLng($utm1);
        echo "Converted to Lat/Long: " . $ll3->toString();
      ?>
    </p>

    <h2>Convert Latitude/Longitude to UTM Reference</h2>

    <p>
      <pre>
        $ll4 = new LatLng(-60.1167, -111.7833);
        $utm2 = LatLngToOSRef($ll4);
      </pre>

      <?php
        $ll4 = new LatLng(-60.1167, -111.7833);
        echo "Latitude/Longitude: " . $ll4->toString() . "<br />";
        $utm2 = LatLngToUTMRef($ll4);
        echo "Converted to UTM Ref: " . $utm2->toString() ;
      ?>
    </p>

    <p>
      (c) 2005, Jonathan Stott
    </p>

  </body>
</html>